@@ -34,7 +34,6 @@ import attr
 
 from hypothesis.errors import InvalidArgument, HypothesisDeprecationWarning
 from hypothesis.configuration import hypothesis_home_dir
-from hypothesis.internal.compat import PYPY
 from hypothesis.utils.conventions import UniqueIdentifier, not_set
 from hypothesis.utils.dynamicvariables import DynamicVariable
 
@@ -649,15 +648,15 @@ deadline and have not explicitly set a deadline yourself.
 
 settings.define_setting(
     'use_coverage',
-    default=not PYPY,
-    show_default=False,
+    default=True,
     description="""
 Whether to use coverage information to improve Hypothesis's ability to find
-bugs. You should generally leave this turned on unless your code performs
-poorly when run under coverage.
+bugs.
 
-Note: This is turned on by default except on pypy, where coverage performance
-is sufficiently poor as to make this unusable.
+You should generally leave this turned on unless your code performs
+poorly when run under coverage. If you turn it off, please file a bug report
+or add a comment to an existing one about the problem that prompted you to do
+so.
 """
 )
 
